# Configuring the E-Mail Channel
### On this page
  * [Workspace Notifications](https://help.sap.com/docs/leanix/ea/configuring-e-mail-channel#workspace-notifications)
  * [Customizing the Email Template](https://help.sap.com/docs/leanix/ea/configuring-e-mail-channel#customizing-the-email-template)
  * [Blocked Email Addresses](https://help.sap.com/docs/leanix/ea/configuring-e-mail-channel#blocked-email-addresses)


SAP LeanIX provides flexible email notification options. You can customize the email template and use your own email server. Explore these settings to optimize the visibility and relevance of your email notifications.
